package cfca.paperless.server.business.manager;

package ..deTemp.1751867000646;

import cfca.org.slf4j.Logger;
import cfca.org.slf4j.LoggerFactory;
import cfca.paperless.base.constants.BusiConstants;
import cfca.paperless.base.constants.enums.AuthTypeEnum;
import cfca.paperless.base.constants.enums.CompanyAuthType;
import cfca.paperless.base.constants.enums.IdTypeEnum;
import cfca.paperless.base.constants.enums.PersonIdType;
import cfca.paperless.base.exception.BusinessException;
import cfca.paperless.base.exception.DBAccessException;
import cfca.paperless.base.utils.DesensitizationUtil;
import cfca.paperless.base.utils.ExcelUtil;
import cfca.paperless.base.utils.GUID;
import cfca.paperless.base.utils.GsonUtil;
import cfca.paperless.base.utils.RandomUtil;
import cfca.paperless.base.utils.StringUtil;
import cfca.paperless.base.utils.encrypt.EncryptUtil;
import cfca.paperless.base.utils.image.ImageUtil;
import cfca.paperless.common.spring.security.service.JwtUserService;
import cfca.paperless.server.bean.RealnameAuthStatusInfo;
import cfca.paperless.server.business.common.AccountCommonBusiness;
import cfca.paperless.server.business.common.CompanyAndAccountInfoBusiness;
import cfca.paperless.server.business.common.CompanyOperatorInfoBusiness;
import cfca.paperless.server.business.common.FileStorageBusiness;
import cfca.paperless.server.business.common.RealNameAuthenticationBusiness;
import cfca.paperless.server.business.common.RealnameAuthFlowBusiness;
import cfca.paperless.server.business.common.ToolBusiness;
import cfca.paperless.server.business.contract.SignatoryBusiness;
import cfca.paperless.server.check.AccountCheck;
import cfca.paperless.server.check.CompanyChecker;
import cfca.paperless.server.check.PersonChecker;
import cfca.paperless.server.component.ImageProcessService;
import cfca.paperless.server.component.OuterUserService;
import cfca.paperless.server.dto.bean.AccountBean;
import cfca.paperless.server.dto.bean.CompanyAccountBean;
import cfca.paperless.server.dto.bean.CompanyModel;
import cfca.paperless.server.dto.bean.CompanyOperatorModel;
import cfca.paperless.server.dto.bean.PaymentBankBean;
import cfca.paperless.server.dto.bean.PersonAccountModel;
import cfca.paperless.server.dto.bean.SystemSettingStrategyBean;
import cfca.paperless.server.dto.request.AddCompanyOperatorDTO;
import cfca.paperless.server.dto.request.CreateCompanyAccountDTO;
import cfca.paperless.server.dto.request.ImportCompanyDTO;
import cfca.paperless.server.dto.request.ImportPersonDTO;
import cfca.paperless.server.dto.request.QueryCompanyListDTO;
import cfca.paperless.server.dto.request.QueryCompanyOperatorDTO;
import cfca.paperless.server.dto.request.QueryPersonAccountListDTO;
import cfca.paperless.server.dto.request.ReqCompanyAccountStartOrStopStatusVO;
import cfca.paperless.server.dto.request.ReqCreatePersonAccountVO;
import cfca.paperless.server.dto.request.ReqPaymentBankListVO;
import cfca.paperless.server.dto.request.ReqQueryCompanyAccountVO;
import cfca.paperless.server.dto.request.ReqResetAccountPasswordVO;
import cfca.paperless.server.dto.request.ReqResetCertificationStatusVO;
import cfca.paperless.server.dto.request.ReqResetCompanyAdminVO;
import cfca.paperless.server.dto.request.ReqUpdateCompanyAccountVO;
import cfca.paperless.server.dto.request.ReqUpdatePersonAccountVO;
import cfca.paperless.server.dto.request.UpdateCompanyOperatorRoleDTO;
import cfca.paperless.server.dto.response.CompanyOperatorsVO;
import cfca.paperless.server.dto.response.ResPageVO;
import cfca.paperless.server.dto.response.ResPaymentBankListVO;
import cfca.paperless.server.dto.response.ResVO;
import cfca.paperless.server.mq.consumer.ShortMessageSendService;
import cfca.paperless.server.persistence.auto.mapper.SysAccountMapper;
import cfca.paperless.server.persistence.auto.model.Account;
import cfca.paperless.server.persistence.auto.model.AccountFileStorage;
import cfca.paperless.server.persistence.auto.model.AccountPasswordHistory;
import cfca.paperless.server.persistence.auto.model.BizChannel;
import cfca.paperless.server.persistence.auto.model.BizChannelSignatory;
import cfca.paperless.server.persistence.auto.model.Company;
import cfca.paperless.server.persistence.auto.model.CompanyAccount;
import cfca.paperless.server.persistence.auto.model.CompanyPayment;
import cfca.paperless.server.persistence.auto.model.SealWithBLOBs;
import cfca.paperless.server.persistence.auto.model.SysAccount;
import cfca.paperless.server.service.query.AccountFaceQueryService;
import cfca.paperless.server.service.query.AccountQueryService;
import cfca.paperless.server.service.query.BizChannelQueryService;
import cfca.paperless.server.service.query.BizChannelSignatoryQueryService;
import cfca.paperless.server.service.query.CompanyAccountQueryService;
import cfca.paperless.server.service.query.CompanyPaymentQueryService;
import cfca.paperless.server.service.query.CompanyQueryService;
import cfca.paperless.server.service.query.SealQueryService;
import cfca.paperless.server.service.query.SysAccountQueryService;
import cfca.paperless.server.service.query.SysRoleQueryService;
import cfca.paperless.server.service.update.AccountLoginErrorUpdateService;
import cfca.paperless.server.service.update.AccountPasswordHistoryUpdateService;
import cfca.paperless.server.service.update.AccountUpdateService;
import cfca.paperless.server.service.update.BizChannelSignatoryUpdateService;
import cfca.paperless.server.service.update.CompanyAccountUpdateService;
import cfca.paperless.server.service.update.CompanyUpdateService;
import cfca.paperless.server.service.update.SealUpdateService;
import cfca.paperless.server.vo.TokenInfoVO;
import cfca.sadk.util.Base64;
import com.github.pagehelper.Page;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.DisabledException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.commons.CommonsMultipartFile;

@Service
public class AccountManagerBusiness {
  private static final Logger logger = LoggerFactory.getLogger(cfca.paperless.server.business.manager.AccountManagerBusiness.class);
  
  private static final String[] colNamesAccount = new String[] { "realName", "idType", "idNo", "phoneNo", "email" };
  
  private static final String[] colNamesCompany = new String[] { "companyName", "companyIdType", "companyIdNo", "legalName", "legalIdType", "legalIdNo", "accountName", "accountIdType", "accountIdNo", "phoneNo" };
  
  @Autowired
  private CompanyOperatorInfoBusiness companyOperatorInfoBusiness;
  
  @Autowired
  private BizChannelQueryService bizChannelQueryService;
  
  @Autowired
  private CompanyAccountUpdateService companyAccountUpdateService;
  
  @Autowired
  private JwtUserService jwtUserService;
  
  @Autowired
  private SysAccountMapper sysAccountMapper;
  
  @Autowired
  private AccountPasswordHistoryUpdateService accountPasswordHistoryUpdateService;
  
  @Autowired
  private AccountQueryService accountQueryService;
  
  @Autowired
  private AccountUpdateService accountUpdateService;
  
  @Autowired
  private CompanyQueryService companyQueryService;
  
  @Autowired
  private CompanyUpdateService companyUpdateService;
  
  @Autowired
  private CompanyAccountQueryService companyAccountQueryService;
  
  @Autowired
  private CompanyAndAccountInfoBusiness companyAndAccountInfoBusiness;
  
  @Autowired
  private FileStorageBusiness fileStorageBusiness;
  
  @Autowired
  private CompanyPaymentQueryService companyPaymentQueryService;
  
  @Autowired
  private ToolBusiness toolBusiness;
  
  @Autowired
  private AccountFaceQueryService accountFaceQueryService;
  
  @Autowired
  private RealNameAuthenticationBusiness realNameAuthenticationBusiness;
  
  @Autowired
  private SealQueryService sealQueryService;
  
  @Autowired
  private AccountLoginErrorUpdateService accountLoginErrorUpdateService;
  
  @Autowired
  private BizChannelSignatoryUpdateService bizChannelSignatoryUpdateService;
  
  @Autowired
  private ImageProcessService imageProcessService;
  
  @Autowired
  private SealUpdateService sealUpdateService;
  
  @Autowired
  private BizChannelSignatoryQueryService bizChannelSignatoryQueryService;
  
  @Autowired
  private RealnameAuthFlowBusiness realnameAuthFlowBusiness;
  
  @Autowired
  private ShortMessageSendService shortMessageSendService;
  
  @Autowired
  private AccountCommonBusiness accountCommonBusiness;
  
  @Autowired
  private OuterUserService outerUserService;
  
  @Autowired
  private AccountCheck accountCheck;
  
  @Autowired
  private SysRoleQueryService sysRoleQueryService;
  
  @Autowired
  private SignatoryBusiness signatoryBusiness;
  
  @Autowired
  private SysAccountQueryService sysAccountQueryService;
  
  public ResPageVO<PersonAccountModel> listPersons(QueryPersonAccountListDTO reqVO) {
    Page<Account> accountList = this.accountQueryService.listPersons(reqVO);
    List<PersonAccountModel> targetList = new ArrayList<>(accountList.size());
    Map<Long, BizChannel> channelMap = this.bizChannelQueryService.getMap();
    for (Account item : accountList) {
      PersonAccountModel model = convert(item, channelMap);
      targetList.add(model);
    } 
    ResPageVO<PersonAccountModel> pageVO = new ResPageVO(reqVO.getPageNo(), reqVO.getPageSize());
    pageVO.setBeans(targetList);
    pageVO.setTotalCount(accountList.getTotal());
    return pageVO;
  }
  
  private PersonAccountModel convert(Account item, Map<Long, BizChannel> channelMap) {
    PersonAccountModel model = new PersonAccountModel();
    model.setId(item.getId().toString());
    model.setStatus(item.getStatus());
    model.setAccountNo(item.getAccountNo());
    model.setRealName(item.getRealName());
    model.setIdType(item.getIdType());
    model.setIdNoReal(item.getIdNo());
    model.setPhoneNoReal(item.getPhoneNo());
    model.setIdNo(item.getIdNo());
    model.setPhoneNo(item.getPhoneNo());
    model.setEmail(item.getEmail());
    model.setCertificationStatus(item.getCertificationStatus());
    model.setRealnameAuthType(item.getRealnameAuthType());
    model.setPersonRealNameAuthTypeLabel(AuthTypeEnum.getDescription(item.getRealnameAuthType()));
    model.setPhoneNo(DesensitizationUtil.desensitizePhoneNo(model.getPhoneNo()));
    model.setIdNo(DesensitizationUtil.desensitizeIdCardNo(model.getIdNo()));
    List<BizChannelSignatory> channels = this.bizChannelSignatoryQueryService.listPersonChannels(item.getId().longValue());
    model.setBizChannelIdList(getChannelIdList(channels));
    model.setBizChannelName(getChannelNames(channels, channelMap));
    if (item.getTrustSign() != null && item.getTrustSign().shortValue() == 1) {
      model.setTrustSign("云端用户");
      model.setTrustSignId(item.getTrustsignId());
    } else {
      model.setTrustSign("本地用户");
      model.setTrustSignId("-");
    } 
    return model;
  }
  
  public PersonAccountModel queryPersonAccount(long accountId) {
    logger.info("查询个人客户");
    Account account = this.accountQueryService.getAccountById(accountId);
    if (account == null)
      throw new BusinessException("该用户信息不存在。ID=" + accountId); 
    Map<Long, BizChannel> channelMap = this.bizChannelQueryService.getMap();
    PersonAccountModel convert = convert(account, channelMap);
    List<BizChannelSignatory> bizChannelSignatoryList = this.bizChannelSignatoryQueryService.listChannelBySignatoryId(Long.valueOf(accountId), null, 
        Short.valueOf((short)1));
    if (bizChannelSignatoryList != null && bizChannelSignatoryList.size() > 0) {
      List<Long> bizBeanList = new ArrayList<>();
      for (BizChannelSignatory tmp : bizChannelSignatoryList)
        bizBeanList.add(tmp.getBizChannelId()); 
      convert.setBizChannelIdList(bizBeanList);
    } 
    return convert;
  }
  
  public void batchCreatePersonAccount(TokenInfoVO tokenVO, MultipartFile file, ImportPersonDTO reqAccountVO) {
    XSSFWorkbook xssfWorkbook = null;
    try {
      xssfWorkbook = new XSSFWorkbook(file.getInputStream());
      List<Map<String, Object>> list = ExcelUtil.getValue(xssfWorkbook.getSheetAt(0), colNamesAccount);
      ReqCreatePersonAccountVO reqVO = null;
      for (Map<String, Object> map : list) {
        reqVO = (ReqCreatePersonAccountVO)GsonUtil.GsonToBean(GsonUtil.GsonString(map), ReqCreatePersonAccountVO.class);
        reqVO.setBizChannelId(reqAccountVO.getBizChannelId());
        reqVO.setNeedPersonCertification(reqAccountVO.getNeedPersonCertification());
        this.accountCheck.checkCreatePersonAccount(reqVO);
        createPersonAccount(tokenVO, reqVO);
      } 
      xssfWorkbook.close();
    } catch (IOException e) {
      try {
        xssfWorkbook.close();
      } catch (IOException ex) {
        throw new RuntimeException(ex);
      } 
      throw new BusinessException("批量添加用户的操作异常", e);
    } 
  }
  
  @Transactional(rollbackFor = {Exception.class})
  public void createPersonAccount(TokenInfoVO tokenVO, ReqCreatePersonAccountVO reqVO) {
    Long operatorId = tokenVO.getAccountId();
    String accountName = reqVO.getRealName();
    String accountIdType = reqVO.getIdType();
    String accountIdNo = reqVO.getIdNo();
    String phoneNo = reqVO.getPhoneNo();
    String email = reqVO.getEmail();
    Long bizChannelId = reqVO.getBizChannelId();
    Account accountSendMsg = null;
    Account oldAccount = this.companyAndAccountInfoBusiness.getExistAccountByPhoneNo(phoneNo);
    boolean existAccount = false;
    Long oldAccountId = null;
    if (oldAccount != null) {
      existAccount = true;
      oldAccountId = oldAccount.getId();
      accountSendMsg = oldAccount;
    } 
    boolean isInitialPassword = false;
    if (!existAccount) {
      isInitialPassword = true;
      Account newAccount = null;
      Long idCardAFileStorageId = Long.valueOf(-1L);
      Long idCardBFileStorageId = Long.valueOf(-1L);
      String accountNo = GUID.getAccountNo();
      List<Account> accountList = this.accountQueryService.selectAccountByAccountNo(accountNo);
      if (accountList != null && accountList.size() > 0)
        accountNo = GUID.getAccountNo(); 
      String password = RandomUtil.createRandomCode(false, 10);
      newAccount = this.companyAndAccountInfoBusiness.createAccountRecord(operatorId, accountNo, password, accountName, accountIdType, accountIdNo, phoneNo, email, idCardAFileStorageId, idCardBFileStorageId);
      if (PersonChecker.isNoCertification(reqVO.getNeedPersonCertification())) {
        Date currentDate = new Date();
        Account recordOfAccount = new Account();
        recordOfAccount.setId(newAccount.getId());
        recordOfAccount.setOperatorId(operatorId);
        recordOfAccount.setUpdateTime(currentDate);
        recordOfAccount.setCertificationStatus(Short.valueOf((short)1));
        recordOfAccount.setRealnameAuthType(Short.valueOf((short)0));
        recordOfAccount.setRealnameAuthFlowId(Long.valueOf(0L));
        recordOfAccount.setRealnameAuthFlowFinishTime(currentDate);
        this.accountUpdateService.updateAccount(recordOfAccount);
      } 
      oldAccountId = newAccount.getId();
      accountSendMsg = newAccount;
    } 
    BizChannelSignatory biz = this.bizChannelSignatoryQueryService.getBeanByAppId(bizChannelId, oldAccountId, null, Short.valueOf((short)1));
    if (biz == null)
      this.bizChannelSignatoryUpdateService.insert(operatorId, bizChannelId, oldAccountId, Short.valueOf((short)1), null); 
    Short accountType = Short.valueOf((short)1);
    if (StringUtil.isEqual("1", reqVO.getNeedSmsAlarm()) && 
      isInitialPassword)
      try {
        if (1 == accountSendMsg.getIsInitialPassword().shortValue()) {
          String password = EncryptUtil.decrypto(accountSendMsg.getInitialPassword());
          this.shortMessageSendService.doSendPersonAccountCreationMessage(Short.valueOf((short)1), accountSendMsg.getId(), accountSendMsg.getRealName(), accountSendMsg
              .getAccountNo(), password, accountSendMsg.getPhoneNo());
        } 
      } catch (Exception e) {
        logger.error("个人用户创建短信发送失败", e);
      }  
  }
  
  private void createPersonSeal(Long operatorId, String accountName, Account newAccount) {
    logger.info("生成印章图片开始");
    String textContent = accountName;
    String fontFamily = "NSimSun";
    int fontSize = 80;
    String fontColor = "E60012";
    boolean withBorder = false;
    byte[] imageData = this.imageProcessService.createRectanglePng(textContent, fontFamily, fontSize, fontColor, withBorder);
    logger.info("生成印章图片结束");
    float[] imageInfo = ImageUtil.getImageSize(imageData);
    int imageDataSize = imageData.length;
    int dpiX = (int)imageInfo[0];
    int dpiY = (int)imageInfo[1];
    float imageWidth = imageInfo[2];
    float imageHeight = imageInfo[3];
    logger.info("生成印章图片缩略图开始");
    byte[] imageIconData = null;
    try {
      imageIconData = ImageUtil.resizeImageOptimized(imageData, 70);
    } catch (IOException e) {
      logger.error("生成印章图片缩略图的操作异常", e);
      throw new BusinessException("生成印章图片缩略图的操作异常", e);
    } 
    logger.info("生成印章图片缩略图结束");
    String sealCode = GUID.generateId(32);
    String sealName = accountName + "-名章";
    Date currentDate = new Date();
    SealWithBLOBs seal = new SealWithBLOBs();
    seal.setCreatorOwnerType(Short.valueOf((short)2));
    seal.setCreatorId(operatorId);
    seal.setCreateTime(currentDate);
    seal.setOperatorOwnerType(Short.valueOf((short)2));
    seal.setOperatorId(operatorId);
    seal.setUpdateTime(currentDate);
    seal.setStatus(Short.valueOf((short)1));
    seal.setSealCode(sealCode);
    seal.setSealName(sealName);
    seal.setOwnerType(Short.valueOf((short)1));
    seal.setCompanyId(null);
    seal.setAccountId(newAccount.getId());
    seal.setCustomerType(Short.valueOf((short)1));
    seal.setSealType(Short.valueOf((short)21));
    seal.setStartTime(null);
    seal.setEndTime(null);
    seal.setDefaultFlag(Short.valueOf((short)1));
    seal.setGenerateType(Short.valueOf((short)0));
    seal.setUkeyRsaSealDataId(null);
    seal.setUkeySm2SealDataId(null);
    seal.setSoftRsaSealDataId(null);
    seal.setSoftSm2SealDataId(null);
    seal.setImageData(imageData);
    seal.setImageDataSize(Integer.valueOf(imageDataSize));
    seal.setImageIconData(imageIconData);
    seal.setImageWidth(String.valueOf(imageWidth));
    seal.setImageHeight(String.valueOf(imageHeight));
    seal.setImageDpi(dpiX + "/" + dpiY);
    seal.setRemark(null);
    seal.setReviewFlowId(null);
    seal.setReviewStatus(Short.valueOf((short)1));
    logger.info("存储印章数据");
    Long sealId = this.sealUpdateService.insertSeal(seal);
  }
  
  public void updatePersonAccount(TokenInfoVO tokenVO, ReqUpdatePersonAccountVO reqVO) {
    long accountId = Long.parseLong(reqVO.getAccountId());
    String realName = reqVO.getRealName();
    String idNo = reqVO.getIdNo();
    String phoneNo = reqVO.getPhoneNo();
    String email = reqVO.getEmail();
    logger.info("查询个人客户");
    Account oldAccount = this.accountQueryService.getAccountById(accountId);
    if (oldAccount == null) {
      logger.error("该用户信息不存在。accountId={}", Long.valueOf(accountId));
      throw new BusinessException("该用户信息不存在。ID=" + accountId);
    } 
    if (oldAccount.getStatus().shortValue() != 1) {
      logger.error("个人用户状态为非有效状态");
      throw new BusinessException("此客户信息已经存在，状态异常，");
    } 
    boolean beNeedSmsAlarm = StringUtil.isEqual("1", reqVO.getNeedSmsAlarm());
    this.signatoryBusiness.updateAccountInfo(oldAccount, beNeedSmsAlarm, phoneNo, realName, "", idNo, email);
  }
  
  public ResPageVO<CompanyModel> listCompanies(QueryCompanyListDTO reqVO) throws Exception {
    logger.info("查询企业客户列表");
    Page<Company> list = this.companyQueryService.listCompanies(reqVO);
    if (list == null || list.isEmpty()) {
      ResPageVO<CompanyModel> resPageVO = new ResPageVO(reqVO.getPageNo(), reqVO.getPageSize());
      resPageVO.setBeans(new ArrayList());
      return resPageVO;
    } 
    Map<Long, BizChannel> bizChannelMap = this.bizChannelQueryService.getMap();
    List<CompanyModel> targetList = new ArrayList<>(list.size());
    for (Company item : list) {
      CompanyModel companyModel = convertCompanyModel(item, true, bizChannelMap);
      targetList.add(companyModel);
    } 
    ResPageVO<CompanyModel> pageVO = new ResPageVO(reqVO.getPageNo(), reqVO.getPageSize());
    pageVO.setBeans(targetList);
    pageVO.setTotalCount(list.getTotal());
    return pageVO;
  }
  
  private CompanyModel convertCompanyModel(Company company, boolean needAdminName, Map<Long, BizChannel> bizChannelMap) {
    CompanyModel companyModel = new CompanyModel();
    companyModel.setCompanyId(company.getId().toString());
    companyModel.setCompanyName(company.getCompanyName());
    companyModel.setCompanyIdType(company.getCompanyIdType());
    companyModel.setCompanyIdNo(company.getCompanyIdNo());
    companyModel.setLegalName(company.getLegalName());
    companyModel.setCertificationStatus(company.getCertificationStatus());
    companyModel.setAccountCertificationStatus(company.getCertificationStatus());
    companyModel.setStatus(company.getStatus());
    companyModel.setLegalIdNo(DesensitizationUtil.desensitizeIdCardNo(company.getLegalIdNo()));
    companyModel.setLegalIdType(company.getLegalIdType());
    companyModel.setCompanyRealNameAuthTypeLabel(AuthTypeEnum.getDescription(company.getRealnameAuthType()));
    if (company.getTrustSign() != null && company.getTrustSign().shortValue() == 1) {
      companyModel.setTrustSign("云端用户");
      companyModel.setTrustSignId(company.getTrustsignId());
    } else {
      companyModel.setTrustSign("本地用户");
      companyModel.setTrustSignId("-");
    } 
    List<BizChannelSignatory> channels = this.bizChannelSignatoryQueryService.listCompanyChannels(company.getId().longValue());
    companyModel.setBizChannelIdList(getChannelIdList(channels));
    companyModel.setBizChannelName(getChannelNames(channels, bizChannelMap));
    if (needAdminName) {
      Account admin = getCompanyAdminByCompanyId(company.getId().longValue());
      String adminName = (admin == null) ? "" : admin.getRealName();
      companyModel.setAccountName(adminName);
    } 
    return companyModel;
  }
  
  private String getChannelNames(List<BizChannelSignatory> channels, Map<Long, BizChannel> bizChannelMap) {
    if (channels == null || channels.isEmpty())
      return ""; 
    StringBuilder stringBuilder = new StringBuilder();
    for (BizChannelSignatory bizChannelSignatory : channels) {
      Long bizChannelId = bizChannelSignatory.getBizChannelId();
      BizChannel bizChannel = bizChannelMap.get(bizChannelId);
      stringBuilder.append(bizChannel.getBizChannelName()).append(",");
    } 
    stringBuilder.deleteCharAt(stringBuilder.length() - 1);
    return stringBuilder.toString();
  }
  
  private List<Long> getChannelIdList(List<BizChannelSignatory> channels) {
    if (channels == null || channels.isEmpty())
      return new ArrayList<>(); 
    return (List<Long>)channels.stream().map(BizChannelSignatory::getBizChannelId).collect(Collectors.toList());
  }
  
  private Account getCompanyAdminByCompanyId(long companyId) {
    List<CompanyAccount> companyAccountList = listCompanyAccountsByCompanyId(companyId);
    if (companyAccountList == null || companyAccountList.isEmpty())
      return null; 
    CompanyAccount companyAccount = companyAccountList.get(0);
    for (CompanyAccount ca : companyAccountList) {
      Long roleId = ca.getRoleId();
      if (Objects.equals(roleId, Long.valueOf(71L)) || 
        Objects.equals(roleId, Long.valueOf(61L))) {
        companyAccount = ca;
        break;
      } 
    } 
    Account account = this.accountQueryService.getAccountById(companyAccount.getAccountId().longValue());
    return account;
  }
  
  private List<CompanyAccount> listCompanyAccountsByCompanyId(long companyId) {
    return this.companyAccountQueryService.getCompanyAccountByCompanyId(Long.valueOf(companyId));
  }
  
  public CompanyModel getCompanyById(long companyId) {
    Company companyById = this.companyQueryService.getCompanyById(companyId);
    Map<Long, BizChannel> bizChannelMap = this.bizChannelQueryService.getMap();
    return convertCompanyModel(companyById, false, bizChannelMap);
  }
  
  public CompanyOperatorsVO listCompanyOperatorsByCompanyId(long companyId) {
    List<CompanyOperatorModel> list;
    CompanyOperatorsVO companyOperatorsVO = new CompanyOperatorsVO();
    List<CompanyAccount> companyAccountList = listCompanyAccountsByCompanyId(companyId);
    if (companyAccountList == null || companyAccountList.isEmpty()) {
      list = new ArrayList<>();
    } else {
      list = new ArrayList<>(companyAccountList.size());
      for (CompanyAccount companyAccount : companyAccountList)
        list.add(convertCompanyOperator(companyAccount)); 
    } 
    companyOperatorsVO.setCompanyOperatorList(list);
    return companyOperatorsVO;
  }
  
  private CompanyOperatorModel convertCompanyOperator(CompanyAccount companyAccount) {
    CompanyOperatorModel model = new CompanyOperatorModel();
    model.setId(companyAccount.getAccountId().toString());
    model.setRoleId(companyAccount.getRoleId());
    model.setAuthorizationStatus(companyAccount.getAuthorizationStatus().shortValue());
    model.setCompanyAccountStatus(companyAccount.getStatus().shortValue());
    Account account = this.accountQueryService.getAccountById(companyAccount.getAccountId().longValue());
    model.setRealName(account.getRealName());
    model.setIdType(account.getIdType());
    model.setIdTypeDesc(IdTypeEnum.getDescription(account.getIdType()));
    model.setIdNo(DesensitizationUtil.desensitizeIdCardNo(account.getIdNo()));
    model.setPhoneNo(DesensitizationUtil.desensitizePhoneNo(account.getPhoneNo()));
    model.setCertificationStatus(account.getCertificationStatus().shortValue());
    model.setAccountNo(account.getAccountNo());
    boolean needAudit = (companyAccount.getAuthorizationAuthType().shortValue() == 90 && companyAccount.getAuthorizationStatus().shortValue() == 0);
    model.setPersonManualNeeds(needAudit ? 1 : 0);
    return model;
  }
  
  public CompanyAccountBean queryCompanyAccount(TokenInfoVO tokenVO, ReqQueryCompanyAccountVO reqVO) {
    Long operatorId = tokenVO.getAccountId();
    long companyId = Long.parseLong(reqVO.getCompanyId());
    logger.info("查询企业客户");
    Company company = this.companyQueryService.getCompanyById(companyId);
    if (company == null)
      throw new BusinessException("该企业信息不存在。ID=" + companyId); 
    String companyLegalIdNo = company.getLegalIdNo();
    CompanyAccountBean result = new CompanyAccountBean();
    result.setCompanyId(Long.valueOf(companyId));
    result.setCompanyName(company.getCompanyName());
    result.setCompanyIdType(company.getCompanyIdType());
    result.setCompanyIdNo(company.getCompanyIdNo());
    result.setCompanyLegalName(company.getLegalName());
    result.setCompanyLegalIdType(company.getLegalIdType());
    if (1 == company.getCertificationStatus().shortValue()) {
      result.setCompanyLegalIdNo(DesensitizationUtil.desensitizeIdCardNo(companyLegalIdNo));
    } else {
      result.setCompanyLegalIdNo(companyLegalIdNo);
    } 
    result.setCertificationStatus(company.getCertificationStatus());
    result.setCompanyCreateTime(company.getCreateTime());
    result.setCompanyUpdateTime(company.getUpdateTime());
    result.setCompanyCertificationToken(company.getCertificationToken());
    Long licenseFileId = company.getLicenseFileId();
    if (null != licenseFileId && licenseFileId.longValue() > 0L) {
      AccountFileStorage licenseFileStorage = this.fileStorageBusiness.pullAccountFile(licenseFileId);
      if (null != licenseFileStorage.getFileData())
        result.setLicenseImageBase64(Base64.toBase64String(licenseFileStorage.getFileData())); 
    } 
    result.setCompanyRealNameAuthType(Long.valueOf(company.getRealnameAuthType().shortValue()));
    result.setCompanyRealNameAuthTypeLabel(CompanyAuthType.getDescription(Long.valueOf(company.getRealnameAuthType().shortValue())));
    logger.info("查询企业打款数据");
    CompanyPayment companyPaymentOld = this.companyPaymentQueryService.selectRecordByPK(Long.valueOf(companyId));
    if (null != companyPaymentOld) {
      String bankName = null;
      if (StringUtil.isNotEmptyAndNull(companyPaymentOld.getBankId())) {
        ReqPaymentBankListVO reqPaymentBankListVO = new ReqPaymentBankListVO();
        reqPaymentBankListVO.setBankId(companyPaymentOld.getBankId());
        ResPaymentBankListVO resPaymentBankListVO = this.toolBusiness.getPaymentBankList(reqPaymentBankListVO);
        if (null != resPaymentBankListVO && null != resPaymentBankListVO.getBeans())
          bankName = ((PaymentBankBean)resPaymentBankListVO.getBeans().get(0)).getBankName(); 
      } 
      Short checkStatus = companyPaymentOld.getCheckStatus();
      result.setPaymentCheckStatus(checkStatus);
      switch (checkStatus.shortValue()) {
        case 0:
          result.setPaymentAccountName(companyPaymentOld.getAccountName());
          result.setPaymentAccountNo(companyPaymentOld.getAccountNo());
          result.setPaymentBankName(bankName);
          result.setPaymentBusinessToken(companyPaymentOld.getBusinessToken());
          result.setTransferLogId(companyPaymentOld.getTransferLogId());
          result.setTransferDate(companyPaymentOld.getTransferDate());
          result.setTransferResCode(companyPaymentOld.getTransferResCode());
          result.setTransferResMessage(companyPaymentOld.getTransferResMessage());
          break;
        case 1:
          result.setPaymentAccountName(companyPaymentOld.getAccountName());
          result.setPaymentAccountNo(companyPaymentOld.getAccountNo());
          result.setPaymentAmount(companyPaymentOld.getAmount());
          result.setPaymentBankName(bankName);
          result.setPaymentBusinessToken(companyPaymentOld.getBusinessToken());
          result.setTransferLogId(companyPaymentOld.getTransferLogId());
          result.setTransferDate(companyPaymentOld.getTransferDate());
          result.setTransferResCode(companyPaymentOld.getTransferResCode());
          result.setTransferResMessage(companyPaymentOld.getTransferResMessage());
          result.setCheckLogId(companyPaymentOld.getCheckLogId());
          result.setCheckDate(companyPaymentOld.getCheckDate());
          result.setCheckResCode(companyPaymentOld.getCheckResCode());
          result.setCheckResMessage(companyPaymentOld.getCheckResMessage());
          break;
        case 2:
          result.setPaymentAccountName(companyPaymentOld.getAccountName());
          result.setPaymentAccountNo(companyPaymentOld.getAccountNo());
          result.setPaymentAmount(companyPaymentOld.getAmount());
          result.setPaymentBankName(bankName);
          result.setPaymentBusinessToken(companyPaymentOld.getBusinessToken());
          result.setTransferLogId(companyPaymentOld.getTransferLogId());
          result.setTransferDate(companyPaymentOld.getTransferDate());
          result.setTransferResCode(companyPaymentOld.getTransferResCode());
          result.setTransferResMessage(companyPaymentOld.getTransferResMessage());
          result.setCheckLogId(companyPaymentOld.getCheckLogId());
          result.setCheckDate(companyPaymentOld.getCheckDate());
          result.setCheckResCode(companyPaymentOld.getCheckResCode());
          result.setCheckResMessage(companyPaymentOld.getCheckResMessage());
          break;
      } 
    } 
    logger.info("查询企业操作员和管理员");
    List<CompanyAccount> opterList = this.companyAccountQueryService.getCompanyAccountByCompanyId(Long.valueOf(companyId));
    if (opterList != null && opterList.size() > 0) {
      List<AccountBean> companyOpterAccountList = new ArrayList<>();
      for (CompanyAccount tmp : opterList) {
        Long accountId = tmp.getAccountId();
        AccountBean accountBean = new AccountBean();
        Account account = this.accountQueryService.getAccountById(accountId.longValue());
        if (account != null) {
          BeanUtils.copyProperties(account, accountBean);
          accountBean.setIdNo(DesensitizationUtil.desensitizeIdCardNo(account.getIdNo()));
          accountBean.setPhoneNo(DesensitizationUtil.desensitizePhoneNo(account.getPhoneNo()));
          accountBean.setRoleId(tmp.getRoleId());
          accountBean.setIdTypeDesc(PersonIdType.getDescription(account.getIdType()));
          accountBean.setCompanyAccountStatus(tmp.getStatus());
          accountBean.setAuthorizationStatus(tmp.getAuthorizationStatus());
          Short companyCertificationStatus = company.getCertificationStatus();
          if (companyCertificationStatus.shortValue() == 1) {
            Short companyAccountCertificationStatus = tmp.getAuthorizationStatus();
            Short companyAccountRealnameAuthType = tmp.getAuthorizationAuthType();
            if (companyAccountCertificationStatus.shortValue() != 1 && 
              companyAccountRealnameAuthType.shortValue() == 90) {
              RealnameAuthStatusInfo realnameAuthStatusInfo = this.realnameAuthFlowBusiness.getRealnameAuthStatusInfoOfCompanyAccount(tmp);
              int manualAuthStatus = realnameAuthStatusInfo.getManualAuthStatus();
              if (manualAuthStatus == 1)
                accountBean.setPersonManualNeeds(Short.valueOf((short)1)); 
            } 
          } 
          companyOpterAccountList.add(accountBean);
        } 
      } 
      result.setCompanyAccountOpterList(companyOpterAccountList);
    } 
    logger.info("查询企业所属应用");
    List<BizChannelSignatory> bizChannelSignatoryList = this.bizChannelSignatoryQueryService.listChannelBySignatoryId(null, Long.valueOf(companyId), Short.valueOf((short)0));
    if (bizChannelSignatoryList != null && bizChannelSignatoryList.size() > 0) {
      List<Long> bizBeanList = new ArrayList<>();
      for (BizChannelSignatory tmp : bizChannelSignatoryList)
        bizBeanList.add(tmp.getBizChannelId()); 
      result.setBizChannelIdList(bizBeanList);
    } 
    return result;
  }
  
  public void batchCreateCompanyAccount(TokenInfoVO tokenVO, MultipartFile file, ImportCompanyDTO reqCompanyVO) {
    XSSFWorkbook xssfWorkbook = null;
    try {
      xssfWorkbook = new XSSFWorkbook(file.getInputStream());
      List<Map<String, Object>> list = ExcelUtil.getValue(xssfWorkbook.getSheetAt(0), colNamesCompany);
      CreateCompanyAccountDTO reqVO = null;
      for (Map<String, Object> map : list) {
        reqVO = (CreateCompanyAccountDTO)GsonUtil.GsonToBean(GsonUtil.GsonString(map), CreateCompanyAccountDTO.class);
        reqVO.setBizChannelId(reqCompanyVO.getBizChannelId());
        if (reqCompanyVO.getNeedCompanyCertification() != null && reqCompanyVO.getNeedCompanyCertification().intValue() == 0) {
          reqVO.setNeedPersonCertification("0");
          reqVO.setNeedCompanyCertification("0");
        } else {
          reqVO.setNeedPersonCertification("1");
          reqVO.setNeedCompanyCertification("1");
        } 
        reqVO.setNeedSmsAlarm("1");
        this.accountCheck.checkCreateCompanyAccount(reqVO);
        reqVO.setRoleId(Long.valueOf(61L));
        createCompanyAccount(tokenVO, reqVO, true);
      } 
      xssfWorkbook.close();
    } catch (IOException e) {
      try {
        xssfWorkbook.close();
      } catch (IOException ex) {
        throw new RuntimeException(ex);
      } 
      throw new BusinessException("批量添加用户的操作异常", e);
    } 
  }
  
  public void createCompanyAccount(TokenInfoVO tokenVO, CreateCompanyAccountDTO reqVO, boolean beImported) {
    Long operatorId = tokenVO.getAccountId();
    String companyName = reqVO.getCompanyName();
    String companyIdType = reqVO.getCompanyIdType();
    String companyIdNo = reqVO.getCompanyIdNo();
    String legalName = reqVO.getLegalName();
    String legalIdType = reqVO.getLegalIdType();
    String legalIdNo = reqVO.getLegalIdNo();
    String accountName = reqVO.getAccountName();
    String accountIdType = reqVO.getAccountIdType();
    String accountIdNo = reqVO.getAccountIdNo();
    String phoneNo = reqVO.getPhoneNo();
    String email = reqVO.getEmail();
    byte[] certificateFileData = null;
    String needCompanyCertification = reqVO.getNeedCompanyCertification();
    String needPersonCertification = reqVO.getNeedPersonCertification();
    Long bizChannelId = reqVO.getBizChannelId();
    Company oldCompany = this.companyAndAccountInfoBusiness.queryCompanyByCompanyNameOrCompanyIdNo(companyName, companyIdType, companyIdNo);
    boolean existCompany = false;
    Long companyId = null;
    if (oldCompany != null) {
      existCompany = true;
      companyId = oldCompany.getId();
      if (!beImported)
        throw new BusinessException("已存在该统一社会信用代码的企业"); 
    } 
    if (!existCompany) {
      Long licenseFileStorageId = Long.valueOf(-1L);
      Company newCompany = this.companyAndAccountInfoBusiness.createCompanyRecord(operatorId, companyName, companyIdType, companyIdNo, legalName, legalIdType, legalIdNo, licenseFileStorageId);
      if (CompanyChecker.isNoCertification(needCompanyCertification)) {
        Date currentDate = new Date();
        Company recordOfCompany = new Company();
        recordOfCompany.setId(newCompany.getId());
        recordOfCompany.setOperatorId(operatorId);
        recordOfCompany.setUpdateTime(currentDate);
        recordOfCompany.setCertificationStatus(Short.valueOf((short)1));
        recordOfCompany.setRealnameAuthType(Short.valueOf((short)0));
        recordOfCompany.setRealnameAuthFlowId(Long.valueOf(0L));
        recordOfCompany.setRealnameAuthFlowFinishTime(currentDate);
        this.companyUpdateService.updateCompany(recordOfCompany);
        boolean existAutoGenerateSeal = this.sealQueryService.existAutoGenerateSeal((short)0, newCompany.getId().longValue(), (short)4);
        if (existAutoGenerateSeal) {
          logger.info("用户名下此种印章类型已经存在自动生成的印章。");
        } else {
          String sealCode = GUID.generateId(32);
          String sealName = companyName + "-公章";
          createCompanyOuterSeal(operatorId, companyName, newCompany, sealCode, sealName);
        } 
      } 
      companyId = newCompany.getId();
    } 
    BizChannelSignatory biz = this.bizChannelSignatoryQueryService.getBeanByAppId(bizChannelId, null, companyId, Short.valueOf((short)0));
    if (biz == null)
      this.bizChannelSignatoryUpdateService.insert(operatorId, bizChannelId, null, Short.valueOf((short)0), companyId); 
    Account account = this.companyAndAccountInfoBusiness.queryAccountInfo(accountName, accountIdType, accountIdNo, phoneNo);
    boolean existAccount = false;
    Long accountId = null;
    if (account != null) {
      existAccount = true;
      accountId = account.getId();
    } 
    if (!existAccount) {
      String accountNo = GUID.getAccountNo();
      String password = RandomUtil.createRandomCode(false, 10);
      Account newAccount = this.companyAndAccountInfoBusiness.createAccountRecord(operatorId, accountNo, password, accountName, accountIdType, accountIdNo, phoneNo, email, 
          Long.valueOf(-1L), Long.valueOf(-1L));
      if (PersonChecker.isNoCertification(needPersonCertification)) {
        Date currentDate = new Date();
        Account recordOfAccount = new Account();
        recordOfAccount.setId(newAccount.getId());
        recordOfAccount.setOperatorId(operatorId);
        recordOfAccount.setUpdateTime(currentDate);
        recordOfAccount.setCertificationStatus(Short.valueOf((short)1));
        recordOfAccount.setRealnameAuthType(Short.valueOf((short)0));
        recordOfAccount.setRealnameAuthFlowId(Long.valueOf(0L));
        recordOfAccount.setRealnameAuthFlowFinishTime(currentDate);
        this.accountUpdateService.updateAccount(recordOfAccount);
      } 
      account = newAccount;
      accountId = newAccount.getId();
    } 
    BizChannelSignatory bizAccount = this.bizChannelSignatoryQueryService.getBeanByAppId(bizChannelId, accountId, null, Short.valueOf((short)1));
    if (bizAccount == null)
      this.bizChannelSignatoryUpdateService.insert(operatorId, bizChannelId, accountId, Short.valueOf((short)1), null); 
    Short isInitialPassword = account.getIsInitialPassword();
    String accountRoleType = "1";
    List<CompanyAccount> companyAccountList = this.companyOperatorInfoBusiness.queryCompanyAccountInfo(existCompany, existAccount, companyId, accountId, accountRoleType);
    Short authorizationStatus = null;
    CompanyAccount companyAccount = this.companyOperatorInfoBusiness.processCompanyAccountInfo(existCompany, existAccount, operatorId, companyId, accountId, certificateFileData, authorizationStatus, accountRoleType, companyAccountList);
    Long roleIdOfCompanyAccount = companyAccount.getRoleId();
    if (reqVO.getRoleId().longValue() == 71L || reqVO.getRoleId().longValue() == 72L) {
      if (roleIdOfCompanyAccount.longValue() == 61L) {
        companyAccount.setRoleId(Long.valueOf(71L));
      } else {
        companyAccount.setRoleId(Long.valueOf(72L));
      } 
      this.companyAccountUpdateService.updateCompanyAccountByKey(companyAccount);
    } 
    if (CompanyChecker.isNoCertification(needCompanyCertification) && PersonChecker.isNoCertification(needPersonCertification)) {
      Date currentDate = new Date();
      CompanyAccount recordOfCompanyAccount = new CompanyAccount();
      recordOfCompanyAccount.setCompanyId(companyAccount.getCompanyId());
      recordOfCompanyAccount.setAccountId(companyAccount.getAccountId());
      recordOfCompanyAccount.setOperatorId(operatorId);
      recordOfCompanyAccount.setUpdateTime(currentDate);
      recordOfCompanyAccount.setAuthorizationStatus(Short.valueOf((short)1));
      recordOfCompanyAccount.setAuthorizationAuthType(Short.valueOf((short)0));
      recordOfCompanyAccount.setAuthorizationAuthFlowId(Long.valueOf(0L));
      recordOfCompanyAccount.setAuthFlowFinishTime(currentDate);
      int count = this.companyAccountUpdateService.updateCompanyAccountByKey(recordOfCompanyAccount);
      System.err.println(count);
    } 
    if (StringUtil.isEqual("1", reqVO.getNeedSmsAlarm())) {
      if (!StringUtil.isNotEmptyAndNull(account.getPhoneNo()))
        throw new BusinessException("用户手机号未注册"); 
      try {
        String password = BusiConstants.passwordWithX;
        if (1 == isInitialPassword.shortValue())
          password = EncryptUtil.decrypto(account.getInitialPassword()); 
        this.shortMessageSendService.doSendCompanyAccountCreationMessage(Short.valueOf((short)0), companyId, companyName, accountId, accountName, "企业管理员", account
            .getAccountNo(), password, phoneNo);
      } catch (Exception e) {
        logger.error("企业用户创建短信发送失败", e);
      } 
    } 
  }
  
  private void createCompanyOuterSeal(Long operatorId, String companyName, Company newCompany, String sealCode, String sealName) {
    logger.info("生成印章图片开始");
    if (companyName.length() > 40)
      logger.warn("印章图片中企业名称最多支持到40个字符，超过40个字符则可能出现文字过小或重叠的现象。企业名称=[{}]", companyName); 
    String curveTextContent = companyName;
    String curveFontFamily = "NSimSun";
    int curveFontSize = adaptFontSize(companyName);
    String centerTextContent = "";
    String centerFontFamily = "NSimSun";
    int centerFontSize = 40;
    byte[] imageData = this.imageProcessService.createCircleStarPng(curveTextContent, curveFontFamily, curveFontSize, centerTextContent, centerFontFamily, centerFontSize);
    logger.info("生成印章图片结束");
    float[] imageInfo = ImageUtil.getImageSize(imageData);
    int imageDataSize = imageData.length;
    int dpiX = (int)imageInfo[0];
    int dpiY = (int)imageInfo[1];
    float imageWidth = imageInfo[2];
    float imageHeight = imageInfo[3];
    logger.info("生成印章图片缩略图开始");
    byte[] imageIconData = null;
    try {
      imageIconData = ImageUtil.resizeImageOptimized(imageData, 70);
    } catch (IOException e) {
      logger.error("生成印章图片缩略图的操作异常", e);
      throw new BusinessException("生成印章图片缩略图的操作异常", e);
    } 
    logger.info("生成印章图片缩略图结束");
    Date currentDate = new Date();
    SealWithBLOBs seal = new SealWithBLOBs();
    seal.setCreatorOwnerType(Short.valueOf((short)2));
    seal.setCreatorId(operatorId);
    seal.setCreateTime(currentDate);
    seal.setOperatorOwnerType(Short.valueOf((short)2));
    seal.setOperatorId(operatorId);
    seal.setUpdateTime(currentDate);
    seal.setStatus(Short.valueOf((short)1));
    seal.setSealCode(sealCode);
    seal.setSealName(sealName);
    seal.setOwnerType(Short.valueOf((short)0));
    seal.setCompanyId(newCompany.getId());
    seal.setCustomerType(Short.valueOf((short)2));
    seal.setSealType(Short.valueOf((short)1));
    seal.setStartTime(null);
    seal.setEndTime(null);
    seal.setDefaultFlag(Short.valueOf((short)1));
    seal.setGenerateType(Short.valueOf((short)0));
    seal.setUkeyRsaSealDataId(null);
    seal.setUkeySm2SealDataId(null);
    seal.setSoftRsaSealDataId(null);
    seal.setSoftSm2SealDataId(null);
    seal.setImageData(imageData);
    seal.setImageDataSize(Integer.valueOf(imageDataSize));
    seal.setImageIconData(imageIconData);
    seal.setImageWidth(String.valueOf(imageWidth));
    seal.setImageHeight(String.valueOf(imageHeight));
    seal.setImageDpi(dpiX + "/" + dpiY);
    seal.setRemark(null);
    seal.setReviewFlowId(null);
    seal.setReviewStatus(Short.valueOf((short)1));
    logger.info("存储印章数据");
    Long sealId = this.sealUpdateService.insertSeal(seal);
  }
  
  @Transactional
  public void updateCompanyAccount(TokenInfoVO tokenVO, ReqUpdateCompanyAccountVO reqVO) {
    long operatorId = tokenVO.getAccountId().longValue();
    long companyId = Long.parseLong(reqVO.getCompanyId());
    String companyName = reqVO.getCompanyName();
    String legalName = reqVO.getLegalName();
    String legalIdType = reqVO.getLegalIdType();
    String legalIdNo = reqVO.getLegalIdNo();
    String companyIdNo = reqVO.getCompanyIdNo();
    String companyIdType = reqVO.getCompanyIdType();
    logger.info("查询企业客户");
    Company oldCompany = this.companyQueryService.getValidCompanyById(companyId);
    if (oldCompany == null) {
      logger.error("该企业信息不存在。companyId={}", Long.valueOf(companyId));
      throw new BusinessException("该企业信息不存在。ID=" + companyId);
    } 
    String oldCompanyIdNo = oldCompany.getCompanyIdNo();
    if (oldCompany.getStatus().shortValue() != 1) {
      logger.error("接入方或企业数据已经存在，状态为非有效状态");
      throw new BusinessException("此客户信息已经存在，状态异常，请查询编辑相应用户信息。CompanyIdNo=" + oldCompanyIdNo);
    } 
    boolean beNeedSmsAlarm = StringUtil.isEqual("1", reqVO.getNeedSmsAlarm());
    this.signatoryBusiness.updateCompanyInfo(oldCompany, beNeedSmsAlarm, companyName, companyIdType, companyIdNo, legalName, "0", legalIdNo);
  }
  
  public void deleteCompanyAccount(TokenInfoVO tokenVO, long companyId) {
    this.companyAccountUpdateService.deleteCompanyAccountByCompanyId(Long.valueOf(companyId));
    this.bizChannelSignatoryUpdateService.deleteByCompanyId(Long.valueOf(companyId));
    this.companyUpdateService.deleteCompany(Long.valueOf(companyId));
  }
  
  public void enableCompanyAccount(TokenInfoVO tokenVO, long companyId) {
    Long operatorId = tokenVO.getAccountId();
    logger.info("准备启用企业[ID={}]", Long.valueOf(companyId));
    Company company = this.companyQueryService.getCompanyById(companyId);
    if (company == null) {
      logger.error("待操作的企业不存在");
      throw new BusinessException("待操作的企业不存在");
    } 
    short status = company.getStatus().shortValue();
    if (status == 1) {
      logger.error("待操作的企业已经是启用并有效状态");
      throw new BusinessException("待操作的企业已经是启用并有效状态");
    } 
    if (status != 2) {
      logger.error("待操作的企业非停用状态，无法执行启用操作。status={}", Short.valueOf(status));
      throw new BusinessException("待操作的企业非停用状态，无法执行启用操作。");
    } 
    logger.info("待操作企业数据[ID={},status={}]", Long.valueOf(companyId), Short.valueOf(status));
    Company newCompany = new Company();
    newCompany.setId(company.getId());
    newCompany.setOperatorId(operatorId);
    newCompany.setUpdateTime(new Date());
    newCompany.setStatus(Short.valueOf((short)1));
    this.companyUpdateService.updateCompany(newCompany);
    logger.info("已经启用企业[ID={}]", Long.valueOf(companyId));
  }
  
  public void disableCompanyAccount(TokenInfoVO tokenVO, long companyId) {
    Long operatorId = tokenVO.getAccountId();
    logger.info("准备停用企业[ID={}]", Long.valueOf(companyId));
    Company company = this.companyQueryService.getValidCompanyById(companyId);
    if (company == null) {
      logger.error("待操作的企业不存在");
      throw new BusinessException("待操作的企业不存在");
    } 
    short status = company.getStatus().shortValue();
    if (status == 2) {
      logger.error("待操作的企业已经是停用状态");
      throw new BusinessException("待操作的企业已经是停用状态");
    } 
    if (status != 1) {
      logger.error("待操作的企业非启用并有效状态，无法执行停用操作。status={}", Short.valueOf(status));
      throw new BusinessException("待操作的企业非启用并有效状态，无法执行停用操作。");
    } 
    logger.info("待操作企业数据[ID={},status={}]", Long.valueOf(companyId), Short.valueOf(status));
    Company newCompany = new Company();
    newCompany.setId(company.getId());
    newCompany.setOperatorId(operatorId);
    newCompany.setUpdateTime(new Date());
    newCompany.setStatus(Short.valueOf((short)2));
    this.companyUpdateService.updateCompany(newCompany);
    logger.info("已经停用企业[ID={}]", Long.valueOf(companyId));
  }
  
  @Transactional(rollbackFor = {Exception.class})
  public void deletePersonAccount(TokenInfoVO tokenVO, long accountId) {
    this.accountUpdateService.deleteAccount(Long.valueOf(accountId));
    this.companyAccountUpdateService.deleteCompanyAccountByAccountId(Long.valueOf(accountId));
    this.bizChannelSignatoryUpdateService.deleteByAccountId(Long.valueOf(accountId));
  }
  
  public void enablePersonAccount(TokenInfoVO tokenVO, long accountId) {
    Long operatorId = tokenVO.getAccountId();
    logger.info("准备启用个人客户[ID={}]", Long.valueOf(accountId));
    Account account = this.accountQueryService.getAccountById(accountId);
    if (account == null) {
      logger.error("待操作的账户不存在");
      throw new BusinessException("待操作的账户不存在");
    } 
    short status = account.getStatus().shortValue();
    if (status == 1) {
      logger.error("待操作的账户已经是启用并有效状态");
      throw new BusinessException("待操作的账户已经是启用状态");
    } 
    if (status != 2) {
      logger.error("待操作的账户非停用状态，无法执行启用操作。status={}", Short.valueOf(status));
      throw new BusinessException("待操作的账户非停用状态，无法执行启用操作。");
    } 
    logger.info("待操作个人客户数据[ID={},status={}]", Long.valueOf(accountId), Short.valueOf(status));
    Account newAccount = new Account();
    newAccount.setId(account.getId());
    newAccount.setOperatorId(operatorId);
    newAccount.setUpdateTime(new Date());
    newAccount.setStatus(Short.valueOf((short)1));
    this.accountUpdateService.updateAccount(newAccount);
    logger.info("已经启用个人客户[ID={}]", Long.valueOf(accountId));
  }
  
  public void disablePersonAccount(TokenInfoVO tokenVO, long accountId) {
    Long operatorId = tokenVO.getAccountId();
    logger.info("准备停用个人客户[ID={}]", Long.valueOf(accountId));
    Account account = this.accountQueryService.getAccountById(accountId);
    if (account == null) {
      logger.error("待操作的账户不存在");
      throw new BusinessException("待操作的账户不存在");
    } 
    short status = account.getStatus().shortValue();
    if (status == 2) {
      logger.error("待操作的账户已经是停用状态");
      throw new BusinessException("待操作的账户已经是停用状态");
    } 
    if (status != 1) {
      logger.error("待操作的账户非启用并有效状态，无法执行停用操作。status={}", Short.valueOf(status));
      throw new BusinessException("待操作的账户非启用并有效状态，无法执行停用操作。");
    } 
    logger.info("待操作个人客户数据[ID={},status={}]", Long.valueOf(accountId), Short.valueOf(status));
    Account newAccount = new Account();
    newAccount.setId(account.getId());
    newAccount.setOperatorId(operatorId);
    newAccount.setUpdateTime(new Date());
    newAccount.setStatus(Short.valueOf((short)2));
    this.accountUpdateService.updateAccount(newAccount);
    logger.info("已经停用个人客户[ID={}]", Long.valueOf(accountId));
  }
  
  public void resetCompanyAdmin(TokenInfoVO tokenVO, ReqResetCompanyAdminVO reqVO) {
    long operatorId = tokenVO.getAccountId().longValue();
    Long companyId = reqVO.getCompanyId();
    String accountName = reqVO.getAccountName();
    String accountIdType = reqVO.getAccountIdType();
    String accountIdNo = reqVO.getAccountIdNo();
    String phoneNo = reqVO.getPhoneNo();
    String email = reqVO.getEmail();
    Company company = this.companyQueryService.getValidCompanyById(companyId.longValue());
    if (company == null) {
      logger.error("企业数据不存在。companyId={}", companyId);
      throw new BusinessException("企业数据不存在。companyId=" + companyId);
    } 
    boolean existCompany = true;
    Account account = this.companyAndAccountInfoBusiness.queryAccountInfo(accountName, accountIdType, accountIdNo, phoneNo);
    boolean existAccount = false;
    Long accountId = null;
    if (account != null) {
      existAccount = true;
      accountId = account.getId();
    } 
    byte[] idCardFileDataA = null;
    byte[] idCardFileDataB = null;
    byte[] certificateFileData = null;
    String authenticationFlag = "2";
    account = this.companyAndAccountInfoBusiness.processAccountInfo(existAccount, account, accountId, Long.valueOf(operatorId), authenticationFlag, accountName, accountIdType, accountIdNo, phoneNo, email, idCardFileDataA, idCardFileDataB);
    accountId = account.getId();
    String accountRoleType = "1";
    List<CompanyAccount> companyAccountList = this.companyOperatorInfoBusiness.queryCompanyAccountInfo(existCompany, existAccount, companyId, accountId, accountRoleType);
    Short authorizationStatus = null;
    CompanyAccount companyAccount = this.companyOperatorInfoBusiness.processCompanyAccountInfo(existCompany, existAccount, Long.valueOf(operatorId), companyId, accountId, certificateFileData, authorizationStatus, accountRoleType, companyAccountList);
  }
  
  public void resetPassword(TokenInfoVO tokenVO, ReqResetAccountPasswordVO reqVO) {
    Long operatorId = tokenVO.getAccountId();
    Long accountId = reqVO.getAccountId();
    String password = reqVO.getPassword();
    String serverRandomId = reqVO.getServerRandomId();
    String clientRandom = reqVO.getClientRandom();
    String passwordOld = reqVO.getPasswordOld();
    String serverRandomIdOld = reqVO.getServerRandomIdOld();
    String clientRandomOld = reqVO.getClientRandomOld();
    Account account = this.accountQueryService.getAccountById(accountId.longValue());
    if (account == null)
      throw new BusinessException("该用户信息不存在。ID=" + accountId); 
    SysAccount sysAccount = this.sysAccountQueryService.getAccountById(operatorId.longValue());
    if (sysAccount == null)
      throw new BusinessException("该登录用户信息不存在。ID=" + operatorId); 
    String newPassword = null;
    String plainPassword = null;
    String oldPassword = null;
    try {
      newPassword = this.jwtUserService.getRealPassword(serverRandomId, clientRandom, password);
      plainPassword = this.jwtUserService.getRealPassword(serverRandomId, clientRandom, password, false);
      oldPassword = this.jwtUserService.getRealPassword(serverRandomIdOld, clientRandomOld, passwordOld);
    } catch (DisabledException e) {
      throw new BusinessException("1050", new Object[] { e.getMessage() });
    } 
    Date currentDate = new Date();
    short isInitialPassword = 0;
    if (!sysAccount.getPassword().equals(oldPassword))
      throw new BusinessException("2078", new Object[] { "登录密码错误,不能修改密码" }); 
    if (account.getPassword().equals(newPassword))
      throw new BusinessException("2078", new Object[] { "新密码不能和原密码相同" }); 
    int res = this.accountUpdateService.updateAccountPasswordById(operatorId, currentDate, accountId, newPassword, Short.valueOf(isInitialPassword));
    if (res != 1)
      throw new DBAccessException("2003"); 
    AccountPasswordHistory record = new AccountPasswordHistory();
    record.setCreatorOwnerType(Short.valueOf((short)2));
    record.setCreatorId(operatorId);
    record.setCreateTime(currentDate);
    record.setOwnerType(Short.valueOf((short)1));
    record.setAccountId(accountId);
    record.setPassword(newPassword);
    record.setIsInitialPassword(Short.valueOf(isInitialPassword));
    this.accountPasswordHistoryUpdateService.insertRecord(record);
    this.shortMessageSendService.doSendResetPasswordMessage(Short.valueOf((short)1), null, null, accountId, account.getRealName(), account.getPhoneNo(), plainPassword);
  }
  
  public void resetCertificationStatus(ReqResetCertificationStatusVO reqVO) {
    if (StringUtil.isNotEmptyAndNull(reqVO.getAccountId()))
      if (StringUtil.isEqual("1", reqVO.getNeedCertification())) {
        Account accountInfo = this.accountQueryService.getAccountById(Long.parseLong(reqVO.getAccountId()));
        personCertification(accountInfo);
      } else {
        if (StringUtil.isEmpty(reqVO.getCertificationStatus()))
          throw new BusinessException("实名认证状态设置不能为空"); 
        Account account = new Account();
        account.setId(Long.valueOf(Long.parseLong(reqVO.getAccountId())));
        account.setUpdateTime(new Date());
        account.setCertificationStatus(Short.valueOf(Short.parseShort(reqVO.getCertificationStatus())));
        account.setCertificationToken("0");
        account.setRealnameAuthType(Short.valueOf((short)0));
        int count = this.accountUpdateService.updateAccount(account);
        if (count != 1)
          throw new DBAccessException("2003"); 
      }  
    if (StringUtil.isNotEmptyAndNull(reqVO.getCompanyId()))
      if (StringUtil.isEqual("1", reqVO.getNeedCertification())) {
        Company companyInfo = this.companyQueryService.getValidCompanyById(Long.parseLong(reqVO.getCompanyId()));
        companyCertification(companyInfo);
      } else {
        if (StringUtil.isEmpty(reqVO.getCertificationStatus()))
          throw new BusinessException("实名认证状态设置不能为空"); 
        Company company = new Company();
        company.setId(Long.valueOf(Long.parseLong(reqVO.getCompanyId())));
        company.setUpdateTime(new Date());
        company.setCertificationStatus(Short.valueOf(Short.parseShort(reqVO.getCertificationStatus())));
        company.setCertificationToken("0");
        company.setRealnameAuthType(Short.valueOf((short)0));
        int count = this.companyUpdateService.updateCompany(company);
        if (count != 1)
          throw new DBAccessException("2003"); 
      }  
  }
  
  public ResVO unlockAccount(TokenInfoVO tokenVO, Long accountId) {
    Long operatorId = tokenVO.getAccountId();
    this.accountLoginErrorUpdateService.updateByKey((short)1, accountId.longValue(), (short)0, new Date());
    int res = this.accountUpdateService.updateAccountStatusById(operatorId, accountId, Short.valueOf((short)1));
    if (res != 1)
      throw new DBAccessException("2003"); 
    return new ResVO();
  }
  
  private SystemSettingStrategyBean companyCertification(Company company) {
    if (null == company)
      throw new BusinessException("不存在的企业用户"); 
    if (StringUtil.isEmpty(company.getCompanyIdType()))
      throw new BusinessException("企业实名认证失败: 企业证件类型不能为空"); 
    if (StringUtil.isEmpty(company.getCompanyIdNo()))
      throw new BusinessException("企业实名认证失败: 企业证件号不能为空"); 
    if (StringUtil.isEmpty(company.getLegalName()))
      throw new BusinessException("企业实名认证失败: 企业法人姓名不能为空"); 
    if (StringUtil.isEmpty(company.getLegalIdNo()))
      throw new BusinessException("企业实名认证失败: 企业法人身份证号不能为空"); 
    SystemSettingStrategyBean systemSettingStrategyBean = this.realNameAuthenticationBusiness.getCompanyCertificationStrategy(true, company, null);
    this.realNameAuthenticationBusiness.authCompanyFlow(null, company, null, systemSettingStrategyBean, false);
    return systemSettingStrategyBean;
  }
  
  private SystemSettingStrategyBean personCertification(Account account) {
    if (null == account)
      throw new BusinessException("不存在的个人用户"); 
    if (StringUtil.isEmpty(account.getIdNo()))
      throw new BusinessException("个人实名认证失败: 身份证件号不能为空"); 
    if (StringUtil.isEmpty(account.getRealName()))
      throw new BusinessException("个人实名认证失败: 姓名不能为空"); 
    if (StringUtil.isEmpty(account.getPhoneNo()))
      throw new BusinessException("个人实名认证失败: 手机号不能为空"); 
    SystemSettingStrategyBean systemSettingStrategyBean = this.realNameAuthenticationBusiness.getPersonCertificationStrategy(true, account, null);
    this.realNameAuthenticationBusiness.authPersonFlow(null, account, systemSettingStrategyBean, false);
    return systemSettingStrategyBean;
  }
  
  private int adaptFontSize(String companyNameString) {
    int textLength = StringUtil.isNotEmptyAndNull(companyNameString) ? companyNameString.length() : 0;
    int fontSize = 60;
    if (textLength >= 0 && textLength <= 14) {
      fontSize = 60;
    } else if (textLength > 14 && textLength <= 16) {
      fontSize = 55;
    } else if (textLength > 16 && textLength <= 18) {
      fontSize = 50;
    } else if (textLength > 18 && textLength <= 21) {
      fontSize = 45;
    } else if (textLength > 21 && textLength <= 24) {
      fontSize = 40;
    } else if (textLength > 24 && textLength <= 28) {
      fontSize = 35;
    } else if (textLength > 28 && textLength <= 34) {
      fontSize = 30;
    } else if (textLength > 34 && textLength <= 36) {
      fontSize = 28;
    } else if (textLength > 36 && textLength <= 40) {
      fontSize = 26;
    } else if (textLength > 40 && textLength <= 45) {
      fontSize = 24;
    } else if (textLength > 45 && textLength <= 50) {
      fontSize = 23;
    } else {
      fontSize = 22;
    } 
    return fontSize;
  }
  
  public void startOrStopCompanyOperator(TokenInfoVO tokenVO, ReqCompanyAccountStartOrStopStatusVO reqVO) {
    Long accountId = Long.valueOf(Long.parseLong(reqVO.getAccountId()));
    Long companyId = Long.valueOf(Long.parseLong(reqVO.getCompanyId()));
    Short status = reqVO.getStatus();
    CompanyAccount record = new CompanyAccount();
    record.setAccountId(accountId);
    record.setCompanyId(companyId);
    record.setStatus(status);
    this.companyAccountUpdateService.updateCompanyAccountByKey(record);
  }
  
  public void addCompanyOperator(TokenInfoVO tokenVO, AddCompanyOperatorDTO reqVO, CommonsMultipartFile fileAuthAgreement) {
    Long operatorId = tokenVO.getAccountId();
    Long accountId = Long.valueOf(Long.parseLong(reqVO.getAccountId()));
    Long companyId = Long.valueOf(Long.parseLong(reqVO.getCompanyId()));
    short authStatus = Short.parseShort(reqVO.getAuthStatus());
    String isAdmin = reqVO.getIsAdmin();
    String isAbleSendContract = reqVO.getIsAbleSendContract();
    Company company = this.companyQueryService.getValidCompanyById(companyId.longValue());
    if (company == null)
      throw new BusinessException("该企业信息不存在。ID=" + companyId); 
    Account account = this.accountQueryService.getAccountById(accountId.longValue());
    if (account == null)
      throw new BusinessException("该用户信息不存在。ID=" + accountId); 
    CompanyAccount oldCompanyAccount = this.companyAccountQueryService.getCompanyAccountByPrimaryKey(companyId, accountId);
    CompanyAccount record = new CompanyAccount();
    record.setAccountId(accountId);
    record.setCompanyId(companyId);
    record.setAuthorizationStatus(Short.valueOf(authStatus));
    if (authStatus == 1) {
      byte[] authorizationData = fileAuthAgreement.getBytes();
      AccountFileStorage authorizationFileStorage = this.fileStorageBusiness.pushAccountFile("PowerOfAttorney", "png", authorizationData, 
          Short.valueOf((short)31));
      Long authorizationFileId = Long.valueOf((authorizationFileStorage == null) ? -1L : authorizationFileStorage.getId().longValue());
      record.setAuthFlowFinishTime(new Date());
      record.setAuthorizationAuthType(Short.valueOf((short)0));
      record.setAuthorizationFileId(authorizationFileId);
    } 
    String role = "企业管理员";
    if ("1".equals(isAdmin)) {
      role = "企业管理员";
      record.setRoleId(Long.valueOf(61L));
      if ("1".equals(isAbleSendContract))
        record.setRoleId(Long.valueOf(71L)); 
      downRoleToOperator(companyId);
    } else {
      role = "企业操作员";
      record.setRoleId(Long.valueOf(62L));
      if ("1".equals(isAbleSendContract))
        record.setRoleId(Long.valueOf(72L)); 
    } 
    if (oldCompanyAccount == null) {
      record.setCreatorId(operatorId);
      record.setOperatorId(operatorId);
      record.setCreateTime(new Date());
      record.setUpdateTime(new Date());
      record.setStatus(Short.valueOf((short)1));
      this.companyAccountUpdateService.insertCompanyAccount(record);
    } else {
      this.companyAccountUpdateService.updateCompanyAccountByKey(record);
    } 
    if (!StringUtil.isNotEmptyAndNull(account.getPhoneNo()))
      throw new BusinessException("用户手机号未注册"); 
    try {
      String password = BusiConstants.passwordWithX;
      if (1 == account.getIsInitialPassword().shortValue())
        password = EncryptUtil.decrypto(account.getInitialPassword()); 
      this.shortMessageSendService.doSendCompanyAccountCreationMessage(Short.valueOf((short)0), companyId, company.getCompanyName(), accountId, account
          .getRealName(), role, account.getAccountNo(), password, account.getPhoneNo());
    } catch (Exception e) {
      logger.error("企业用户创建短信发送失败", e);
    } 
  }
  
  public void changeCompanyAccountRole(TokenInfoVO tokenVO, UpdateCompanyOperatorRoleDTO reqVO) {
    long companyId = Long.parseLong(reqVO.getCompanyId());
    Long accountId = Long.valueOf(Long.parseLong(reqVO.getAccountId()));
    Long roleId = Long.valueOf(Long.parseLong(reqVO.getRoleId()));
    if (61L == roleId.longValue() || 71L == roleId.longValue())
      downRoleToOperator(Long.valueOf(companyId)); 
    CompanyAccount record = new CompanyAccount();
    record.setAccountId(accountId);
    record.setCompanyId(Long.valueOf(companyId));
    record.setRoleId(roleId);
    this.companyAccountUpdateService.updateCompanyAccountByKey(record);
  }
  
  public void deleteCompanyAccountRelation(TokenInfoVO tokenVO, QueryCompanyOperatorDTO reqVO) {
    long companyId = Long.parseLong(reqVO.getCompanyId());
    Long accountId = Long.valueOf(Long.parseLong(reqVO.getAccountId()));
    this.companyAccountUpdateService.deleteCompanyAccountByKey(Long.valueOf(companyId), accountId);
  }
  
  public String getAuthorizationLetter(TokenInfoVO tokenVO, QueryCompanyOperatorDTO reqVO) {
    long companyId = Long.parseLong(reqVO.getCompanyId());
    Long accountId = Long.valueOf(Long.parseLong(reqVO.getAccountId()));
    String result = "";
    CompanyAccount companyAccount = this.companyAccountQueryService.getCompanyAccountByPrimaryKey(Long.valueOf(companyId), accountId);
    Long authFileId = companyAccount.getAuthorizationFileId();
    if (null != authFileId && authFileId.longValue() > 0L) {
      AccountFileStorage licenseFileStorage = this.fileStorageBusiness.pullAccountFile(authFileId);
      if (null != licenseFileStorage.getFileData())
        result = Base64.toBase64String(licenseFileStorage.getFileData()); 
    } 
    return result;
  }
  
  public void checkAuthFactByService(TokenInfoVO tokenVO, ReqQueryCompanyAccountVO reqVO) {
    if (StringUtil.isNotEmptyAndNull(reqVO.getAccountId())) {
      Long accountId = Long.valueOf(Long.parseLong(reqVO.getAccountId()));
      Account account = this.accountQueryService.getAccountById(accountId.longValue());
      if (account == null)
        throw new BusinessException("该用户信息不存在。ID=" + accountId); 
      this.accountCommonBusiness.checkAuthFactByServiceCommon(account, null);
    } 
    if (StringUtil.isNotEmptyAndNull(reqVO.getCompanyId())) {
      Long companyId = Long.valueOf(Long.parseLong(reqVO.getCompanyId()));
      Company company = this.companyQueryService.getCompanyById(companyId.longValue());
      if (company == null)
        throw new BusinessException("该用户信息不存在。ID=" + companyId); 
      this.accountCommonBusiness.checkAuthFactByServiceCommon(null, company);
    } 
  }
  
  private void downRoleToOperator(Long companyId) {
    List<CompanyAccount> companyAccount = this.companyAccountQueryService.getCompanyAccountByCompanyId(companyId);
    if (companyAccount != null && companyAccount.size() > 0)
      for (CompanyAccount tmp : companyAccount) {
        Long tmpRoleId = tmp.getRoleId();
        if (61L == tmpRoleId.longValue()) {
          tmpRoleId = Long.valueOf(62L);
        } else if (71L == tmpRoleId.longValue()) {
          tmpRoleId = Long.valueOf(72L);
        } 
        CompanyAccount newRecord = new CompanyAccount();
        newRecord.setRoleId(tmpRoleId);
        this.companyAccountUpdateService.updateCompanyAccountByKey(newRecord, tmp);
      }  
  }
}
